/*
 * Copyright (c) 2006-2021, RT-Thread Development Team
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Change Logs:
 * Date           Author       Notes
 * 2024-04-23     lijian       the first version
 */
#ifndef APPLICATIONS_THREAD_THREAD_H_
#define APPLICATIONS_THREAD_THREAD_H_

#include <rtthread.h>
#include <drv_common.h>
#include <rtdevice.h>
#include <inout.h>
#include <LTE.h>
#include <mb85rs.h>
#include <gui.h>
//#include <modbus_rtu.h>
#include <DATU.h>
#include <console.h>
#include <mqtt.h>
#include <adc.h>

#define THREAD_PRIORITY_5         5
#define THREAD_PRIORITY_6         6
#define THREAD_PRIORITY_7         7
#define THREAD_PRIORITY_8         8
#define THREAD_PRIORITY_9         9

#define THREAD_STACK_SIZE_1024    1024
#define THREAD_STACK_SIZE_2048    2048
#define THREAD_STACK_SIZE_512     512
#define THREAD_STACK_SIZE_256     256
#define THREAD_STACK_SIZE_128     128
#define THREAD_TIMESLICE_3        3
#define THREAD_TIMESLICE_5        5
#define THREAD_TIMESLICE_6        6
#define THREAD_TIMESLICE_10       10

rt_uint8_t thread_IO_Key(void);
rt_uint8_t thread_IO_Needle(void);
rt_uint8_t thread_IO_ADC(void);
rt_uint8_t thread_Wireless(void);
rt_uint8_t thread_485(void);
rt_uint8_t thread_LCD(void);
rt_uint8_t thread_Yields(void);
rt_uint8_t thread_Check_Save(void);

#endif /* APPLICATIONS_THREAD_THREAD_H_ */
