/*
 * Copyright (c) 2006-2024, RT-Thread Development Team
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Change Logs:
 * Date           Author       Notes
 * 2024-05-04     RT-Thread    first version
 */

#include <rtthread.h>

#define DBG_TAG "main"
#define DBG_LVL DBG_LOG
#include <rtdbg.h>
#include <thread.h>
#include <mb85rs.h>
#include <console.h>

int main(void)
{
    spi_flash_mb85rs_init();
    read_config();

    thread_IO_Key();
    thread_Wireless();
    thread_LCD();
    thread_IO_Needle();
    thread_485();
    thread_IO_ADC();
    thread_Check_Save();
    while (1)
    {
       // LOG_D("Hello RT-Thread!");
        rt_thread_mdelay(10);
    }

    return RT_EOK;
}




